@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IMailboxItems_VERSION = "4.1.57027"
+IMailboxItems_VERSION = "4.1.60051"
 
 class IMailboxItems(BaseEndpoint):
     def __init__(self, apiKey, url ,replicatedMailboxUid ):
@@ -169,6 +169,14 @@ class IMailboxItems(BaseEndpoint):
 
         response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxItems_VERSION}, data = __encoded__);
         return self.handleResult__(serder.LONG, response)
+    def expunge (self):
+        postUri = "/_expunge";
+        __data__ = None
+        __encoded__ = None
+        queryParams = {  };
+
+        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxItems_VERSION}, data = __encoded__);
+        return self.handleResult__(None, response)
     def count (self, arg0 ):
         postUri = "/_count";
         __data__ = None
