@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IPublishCalendar_VERSION = "4.1.57027"
+IPublishCalendar_VERSION = "4.1.60051"
 
 class IPublishCalendar(BaseEndpoint):
     def __init__(self, apiKey, url ,containerUid ):
@@ -69,3 +69,12 @@ class IPublishCalendar(BaseEndpoint):
 
         response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IPublishCalendar_VERSION}, data = __encoded__);
         return response.content
+    def createUrl (self, mode , token ):
+        postUri = "/_create/{mode}";
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{mode}",mode);
+        queryParams = {   'token': token   };
+
+        response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IPublishCalendar_VERSION}, data = __encoded__);
+        return self.handleResult__(serder.STRING, response)
