@@ -38,6 +38,8 @@ class ICalendarElement :
         self.rrule = None
         self.url = None
         self.conference = None
+        self.conferenceId = None
+        self.conferenceConfiguration = None
         self.attachments = None
         self.sequence = None
         self.draft = None
@@ -108,6 +110,10 @@ class __ICalendarElementSerDer__:
         instance.url = serder.STRING.parse(urlValue)
         conferenceValue = value['conference']
         instance.conference = serder.STRING.parse(conferenceValue)
+        conferenceIdValue = value['conferenceId']
+        instance.conferenceId = serder.STRING.parse(conferenceIdValue)
+        conferenceConfigurationValue = value['conferenceConfiguration']
+        instance.conferenceConfiguration = serder.MapSerDer(serder.STRING).parse(conferenceConfigurationValue)
         from netbluemind.attachment.api.AttachedFile import AttachedFile
         from netbluemind.attachment.api.AttachedFile import __AttachedFileSerDer__
         attachmentsValue = value['attachments']
@@ -179,6 +185,10 @@ class __ICalendarElementSerDer__:
         instance["url"] = serder.STRING.encode(urlValue)
         conferenceValue = value.conference
         instance["conference"] = serder.STRING.encode(conferenceValue)
+        conferenceIdValue = value.conferenceId
+        instance["conferenceId"] = serder.STRING.encode(conferenceIdValue)
+        conferenceConfigurationValue = value.conferenceConfiguration
+        instance["conferenceConfiguration"] = serder.MapSerDer(serder.STRING).encode(conferenceConfigurationValue)
         from netbluemind.attachment.api.AttachedFile import AttachedFile
         from netbluemind.attachment.api.AttachedFile import __AttachedFileSerDer__
         attachmentsValue = value.attachments
