@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IInternalHotUpgrade_VERSION = "4.1.57027"
+IInternalHotUpgrade_VERSION = "4.1.60051"
 
 class IInternalHotUpgrade(BaseEndpoint):
     def __init__(self, apiKey, url ):
@@ -30,13 +30,32 @@ class IInternalHotUpgrade(BaseEndpoint):
         self.apiKey = apiKey
         self.base = url +'/hot_upgrade'
 
-    def start (self):
+    def startLimited (self, maxDuration , mode ):
+        postUri = "/limitedStart";
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{maxDuration}",maxDuration);
+        from netbluemind.system.api.hot.upgrade.HotUpgradeTaskExecutionMode import HotUpgradeTaskExecutionMode
+        from netbluemind.system.api.hot.upgrade.HotUpgradeTaskExecutionMode import __HotUpgradeTaskExecutionModeSerDer__
+        __data__ = __HotUpgradeTaskExecutionModeSerDer__().encode(mode)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {    };
+
+        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInternalHotUpgrade_VERSION}, data = __encoded__);
+        from netbluemind.core.task.api.TaskRef import TaskRef
+        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
+        return self.handleResult__(__TaskRefSerDer__(), response)
+    def start (self, mode ):
         postUri = "/start";
         __data__ = None
         __encoded__ = None
-        queryParams = {  };
+        from netbluemind.system.api.hot.upgrade.HotUpgradeTaskExecutionMode import HotUpgradeTaskExecutionMode
+        from netbluemind.system.api.hot.upgrade.HotUpgradeTaskExecutionMode import __HotUpgradeTaskExecutionModeSerDer__
+        __data__ = __HotUpgradeTaskExecutionModeSerDer__().encode(mode)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {   };
 
-        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInternalHotUpgrade_VERSION}, data = __encoded__);
+        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInternalHotUpgrade_VERSION}, data = __encoded__);
         from netbluemind.core.task.api.TaskRef import TaskRef
         from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
         return self.handleResult__(__TaskRefSerDer__(), response)
